(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'melon-calendar', 'melon-timepicker', '../../../factory', 'moment', '../../../util/createStateClassName', '../../ValidityLabel'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('melon-calendar'), require('melon-timepicker'), require('../../../factory'), require('moment'), require('../../../util/createStateClassName'), require('../../ValidityLabel'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.melonCalendar, global.melonTimepicker, global.factory, global.moment, global.createStateClassName, global.ValidityLabel);
        global.DateTime = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _melonCalendar, _melonTimepicker, _factory, _moment, _createStateClassName, _ValidityLabel) {
    'use strict';

    Object.defineProperty(exports, "__esModule", {
        value: true
    });
    exports.default = DateTimeControl;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _melonCalendar2 = _interopRequireDefault(_melonCalendar);

    var _melonTimepicker2 = _interopRequireDefault(_melonTimepicker);

    var _moment2 = _interopRequireDefault(_moment);

    var _createStateClassName2 = _interopRequireDefault(_createStateClassName);

    var _ValidityLabel2 = _interopRequireDefault(_ValidityLabel);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    /**
     * DateTimeControl
     *
     * @class
     * @param {Object} props 属性
     */
    /**
     * @file DateTimeControl
     * @author leon <ludafa@outlook.com>
     */

    function DateTimeControl(props) {
        var schema = props.schema,
            value = props.value,
            name = props.name,
            actions = props.actions,
            meta = props.meta;
        var title = schema.title,
            description = schema.description,
            formatMinimum = schema.formatMinimum,
            formatMaximum = schema.formatMaximum;


        value = (0, _moment2.default)(value);
        value = value.isValid() ? value : (0, _moment2.default)();

        var date = value.format('YYYY-MM-DD');
        var time = value.format('HH:mm:ss');

        var error = meta.error,
            touched = meta.touched;


        var invalid = touched && error && error.message;

        var className = (0, _createStateClassName2.default)('ui-control-datetime', props);

        return _react2.default.createElement(
            'div',
            { className: className },
            title ? _react2.default.createElement(
                'header',
                {
                    className: 'ui-control-datetime-title' },
                title
            ) : null,
            description ? _react2.default.createElement(
                'p',
                {
                    className: 'ui-control-datetime-decription' },
                description
            ) : null,
            _react2.default.createElement(
                'div',
                { className: 'ui-control-datetime-content' },
                _react2.default.createElement(_melonCalendar2.default, {
                    size: 'xs',
                    value: date,
                    begin: formatMinimum,
                    end: formatMaximum,
                    states: { invalid: invalid },
                    onChange: function onChange(e) {
                        actions.change(name, e.value + ' ' + time);
                        actions.validate(name);
                    } }),
                _react2.default.createElement(_melonTimepicker2.default, {
                    size: 'xs',
                    value: time,
                    states: { invalid: invalid },
                    onChange: function onChange(e) {
                        actions.change(name, date + ' ' + e.value);
                        actions.validate(name);
                    } })
            ),
            _react2.default.createElement(_ValidityLabel2.default, meta)
        );
    }

    DateTimeControl.propTypes = {
        schema: _propTypes2.default.object.isRequired,
        value: _propTypes2.default.string
    };

    (0, _factory.registerControl)(function (schema) {

        if (schema.type === 'string' && schema.format === 'date-time') {
            return DateTimeControl;
        }
    });
});
//# sourceMappingURL=DateTime.js.map
